==> jc-1.4.0.tar.gz: gnu/xml/xpath/EqualityExpr.h <==
// final class gnu.xml.xpath.EqualityExpr

// class file dependencies
// @dep_class 242ef307e9043480 gnu_xml_xpath_EqualityExpr
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_xpath_EqualityExpr_H_
#define _JC_gnu_xml_xpath_EqualityExpr_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_EqualityExpr$sub_refs	_jc_gnu_xml_xpath_EqualityExpr$sub_refs;
typedef struct _jc_gnu_xml_xpath_EqualityExpr$sub_nonrefs	_jc_gnu_xml_xpath_EqualityExpr$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_EqualityExpr$refs	_jc_gnu_xml_xpath_EqualityExpr$refs;
typedef struct _jc_gnu_xml_xpath_EqualityExpr$nonrefs	_jc_gnu_xml_xpath_EqualityExpr$nonrefs;
typedef struct _jc_gnu_xml_xpath_EqualityExpr$object	_jc_gnu_xml_xpath_EqualityExpr$object;

typedef const struct _jc_gnu_xml_xpath_EqualityExpr$vmethods	_jc_gnu_xml_xpath_EqualityExpr$vmethods;
typedef const struct _jc_gnu_xml_xpath_EqualityExpr$vtable	_jc_gnu_xml_xpath_EqualityExpr$vtable;
typedef const struct _jc_gnu_xml_xpath_EqualityExpr$vtype	_jc_gnu_xml_xpath_EqualityExpr$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_EqualityExpr$method$_init$63a2fd6a9355b450(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_xpath_Expr$object *, jboolean);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_EqualityExpr$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_EqualityExpr$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_object *, jint, jint);
extern jboolean _jc_gnu_xml_xpath_EqualityExpr$method$evaluateImpl$3cd7c53d9fe90c77(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_object *, jint, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_EqualityExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_EqualityExpr$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_EqualityExpr$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_EqualityExpr$method_info$evaluateImpl$3cd7c53d9fe90c77;
extern _jc_method _jc_gnu_xml_xpath_EqualityExpr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_EqualityExpr$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_object *, jint, jint);
	jboolean	(*evaluateImpl$3cd7c53d9fe90c77)(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_object *, jint, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *);
};

// Vtable
struct _jc_gnu_xml_xpath_EqualityExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_EqualityExpr$vmethods	gnu_xml_xpath_EqualityExpr;
};

// Vtype
struct _jc_gnu_xml_xpath_EqualityExpr$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_EqualityExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_EqualityExpr$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*lhs;
	struct _jc_gnu_xml_xpath_Expr$object	*rhs;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_EqualityExpr$refs {
    _jc_gnu_xml_xpath_EqualityExpr$sub_refs	gnu_xml_xpath_EqualityExpr;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_EqualityExpr$sub_nonrefs {
	jboolean	invert;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_EqualityExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_EqualityExpr$sub_nonrefs	gnu_xml_xpath_EqualityExpr;
};

// Object instance structure
struct _jc_gnu_xml_xpath_EqualityExpr$object {
	_jc_gnu_xml_xpath_EqualityExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_EqualityExpr$vtype	*vtype;
	_jc_gnu_xml_xpath_EqualityExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_EqualityExpr$vtype _jc_gnu_xml_xpath_EqualityExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_EqualityExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_EqualityExpr$class_object;

#endif	/* _JC_gnu_xml_xpath_EqualityExpr_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/EqualityExpr.h <==
// final class gnu.xml.xpath.EqualityExpr

// class file dependencies
// @dep_class 242ef307e9043480 gnu_xml_xpath_EqualityExpr
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_xpath_EqualityExpr_H_
#define _JC_gnu_xml_xpath_EqualityExpr_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_EqualityExpr$sub_refs	_jc_gnu_xml_xpath_EqualityExpr$sub_refs;
typedef struct _jc_gnu_xml_xpath_EqualityExpr$sub_nonrefs	_jc_gnu_xml_xpath_EqualityExpr$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_EqualityExpr$refs	_jc_gnu_xml_xpath_EqualityExpr$refs;
typedef struct _jc_gnu_xml_xpath_EqualityExpr$nonrefs	_jc_gnu_xml_xpath_EqualityExpr$nonrefs;
typedef struct _jc_gnu_xml_xpath_EqualityExpr$object	_jc_gnu_xml_xpath_EqualityExpr$object;

typedef const struct _jc_gnu_xml_xpath_EqualityExpr$vmethods	_jc_gnu_xml_xpath_EqualityExpr$vmethods;
typedef const struct _jc_gnu_xml_xpath_EqualityExpr$vtable	_jc_gnu_xml_xpath_EqualityExpr$vtable;
typedef const struct _jc_gnu_xml_xpath_EqualityExpr$vtype	_jc_gnu_xml_xpath_EqualityExpr$vtype;

// Constructors
extern void _jc_gnu_xml_xpath_EqualityExpr$method$_init$63a2fd6a9355b450(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_gnu_xml_xpath_Expr$object *, struct _jc_gnu_xml_xpath_Expr$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_xpath_EqualityExpr$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_xpath_EqualityExpr$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_xpath_EqualityExpr$method$evaluateImpl$3cd7c53d9fe90c77(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_xpath_EqualityExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_xpath_EqualityExpr$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_xpath_EqualityExpr$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_xpath_EqualityExpr$method_info$evaluateImpl$3cd7c53d9fe90c77;
extern _jc_method _jc_gnu_xml_xpath_EqualityExpr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_xpath_EqualityExpr$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	jboolean	(*evaluateImpl$3cd7c53d9fe90c77)(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_xpath_EqualityExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_xpath_EqualityExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_xpath_EqualityExpr$vmethods	gnu_xml_xpath_EqualityExpr;
};

// Vtype
struct _jc_gnu_xml_xpath_EqualityExpr$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_EqualityExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_EqualityExpr$sub_refs {
	struct _jc_gnu_xml_xpath_Expr$object	*lhs;
	struct _jc_gnu_xml_xpath_Expr$object	*rhs;
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_EqualityExpr$refs {
    _jc_gnu_xml_xpath_EqualityExpr$sub_refs	gnu_xml_xpath_EqualityExpr;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_EqualityExpr$sub_nonrefs {
	jboolean	invert;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_EqualityExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_xpath_EqualityExpr$sub_nonrefs	gnu_xml_xpath_EqualityExpr;
};

// Object instance structure
struct _jc_gnu_xml_xpath_EqualityExpr$object {
	_jc_gnu_xml_xpath_EqualityExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_EqualityExpr$vtype	*vtype;
	_jc_gnu_xml_xpath_EqualityExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_EqualityExpr$vtype _jc_gnu_xml_xpath_EqualityExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_EqualityExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_EqualityExpr$class_object;

#endif	/* _JC_gnu_xml_xpath_EqualityExpr_H_ */
